import { LitElement } from 'lit';
/**
 * Buttons allow users to perform an action when triggered. They feature a text label, a background or a border, and icons.
 *
 * @summary Allows users to perform an action when triggered
 *
 * @fires {Event} pfe-button:click {@deprecated use native click event instead}
 *
 * @cssprop {<color>} --pfe-button--BackgroundColor
 *          no region
 *          {@default var(--pfe-theme--color--ui-accent, #06c)}
 * @cssprop {<color>} --pfe-button--Color
 *          no region
 *          {@default var(--pfe-theme--color--ui-base--text, #fff)}
 * @cssprop --pfe-button--FontSize
 *          no region
 *          {@default var(--pf-global--FontSize--md, 1rem)}
 * @cssprop {normal | bold | bolder | lighter | <number [1,1000]>} --pfe-button--FontWeight
 *          no region
 *          {@default var(--pfe-theme--font-weight--normal, 400)}
 * @cssprop {<length>} --pfe-button--Padding
 *          no region
 *          {@default calc(var(--pfe-theme--container-padding, 1rem) / 2) var(--pfe-theme--container-padding, 1rem)}
 * @cssprop {<length>|<percentage>} --pfe-button--BorderRadius
 *          no region
 *          {@default var(--pfe-theme--surface--border-radius, 3px)}
 * @cssprop {<number>} --pfe-button--LineHeight
 *          no region
 *          {@default var(--pfe-theme--line-height, 1.5)}
 * @cssprop --pfe-button__after--Border
 *          region `after`
 *          {@default var(--pfe-theme--ui--border-width, 1px) var(--pfe-theme--ui--border-style, solid) var(--pfe-button__after--BorderColor, transparent)}
 * @cssprop {<color>} --pfe-button--BackgroundColor--hover
 *          no region
 *          {@default var(--pfe-theme--color--ui-accent--hover, #004080)}
 * @cssprop --pfe-button__after--Border--hover
 *          region `after`
 *          {@default var(--pfe-theme--ui--border-width, 1px) var(--pfe-theme--ui--border-style, solid) var(--pfe-button__after--BorderColor--hover, transparent)}
 * @cssprop --pfe-button--FontWeight--large
 *          no region
 *          {@default var(--pfe-theme--font-weight--semi-bold, 600)}
 * @cssprop --pfe-button--Padding--large
 *          no region
 *          {@default 12px 24px}
 *
 * @csspart container
 */
export declare class PfeButton extends LitElement {
    static readonly version = "{{version}}";
    static readonly styles: import("lit").CSSResult;
    /** Disables the button */
    disabled: boolean;
    /**
     * Changes the style of the button. Possible values are
     *
     * - primary (default)
     * - secondary
     * - tertiary
     * - danger
     * - control
     */
    variant: 'primary' | 'secondary' | 'tertiary' | 'danger' | 'control';
    /** Changes the size of the button. */
    size: 'medium' | 'large';
    type?: 'button' | 'submit' | 'reset';
    private logger;
    private mo;
    private get button();
    connectedCallback(): void;
    render(): import("lit-html").TemplateResult<1>;
    protected _typeChanged(): void;
    protected _disabledChanged(): void;
    private onSlotChange;
    private onClick;
    private onMutation;
}
declare global {
    interface HTMLElementTagNameMap {
        'pfe-button': PfeButton;
    }
}
